==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkRenderWindowInteractor3D.java <==
// java wrapper for vtkRenderWindowInteractor3D object
//

package vtk;
import vtk.*;

public class vtkRenderWindowInteractor3D extends vtkRenderWindowInteractor
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Enable_2();
  public void Enable()
    { Enable_2(); }

  private native void Disable_3();
  public void Disable()
    { Disable_3(); }

  private native void TerminateApp_4();
  public void TerminateApp()
    { TerminateApp_4(); }

  private native long CreateDefaultPicker_5();
  public vtkAbstractPropPicker CreateDefaultPicker() {
    long temp = CreateDefaultPicker_5();

    if (temp == 0) return null;
    return (vtkAbstractPropPicker)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPhysicalEventPosition_6(double id0,double id1,double id2,int id3);
  public void SetPhysicalEventPosition(double id0,double id1,double id2,int id3)
    { SetPhysicalEventPosition_6(id0,id1,id2,id3); }

  private native void SetWorldEventPosition_7(double id0,double id1,double id2,int id3);
  public void SetWorldEventPosition(double id0,double id1,double id2,int id3)
    { SetWorldEventPosition_7(id0,id1,id2,id3); }

  private native void SetWorldEventOrientation_8(double id0,double id1,double id2,double id3,int id4);
  public void SetWorldEventOrientation(double id0,double id1,double id2,double id3,int id4)
    { SetWorldEventOrientation_8(id0,id1,id2,id3,id4); }

  private native void RightButtonPressEvent_9();
  public void RightButtonPressEvent()
    { RightButtonPressEvent_9(); }

  private native void RightButtonReleaseEvent_10();
  public void RightButtonReleaseEvent()
    { RightButtonReleaseEvent_10(); }

  private native void SetTouchPadPosition_11(double id0,double id1);
  public void SetTouchPadPosition(double id0,double id1)
    { SetTouchPadPosition_11(id0,id1); }

  private native void SetTouchPadPosition_12(double id0[]);
  public void SetTouchPadPosition(double id0[])
    { SetTouchPadPosition_12(id0); }

  private native double[] GetTouchPadPosition_13();
  public double[] GetTouchPadPosition()
    { return GetTouchPadPosition_13(); }

  private native void SetPhysicalTranslation_14(vtkCamera id0,double id1,double id2,double id3);
  public void SetPhysicalTranslation(vtkCamera id0,double id1,double id2,double id3)
    { SetPhysicalTranslation_14(id0,id1,id2,id3); }

  private native void SetTranslation3D_15(double id0[]);
  public void SetTranslation3D(double id0[])
    { SetTranslation3D_15(id0); }

  private native double[] GetTranslation3D_16();
  public double[] GetTranslation3D()
    { return GetTranslation3D_16(); }

  private native double[] GetLastTranslation3D_17();
  public double[] GetLastTranslation3D()
    { return GetLastTranslation3D_17(); }

  public vtkRenderWindowInteractor3D() { super(); }

  public vtkRenderWindowInteractor3D(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkRenderWindowInteractor3D.java <==
// java wrapper for vtkRenderWindowInteractor3D object
//

package vtk;
import vtk.*;

public class vtkRenderWindowInteractor3D extends vtkRenderWindowInteractor
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Enable_2();
  public void Enable()
    { Enable_2(); }

  private native void Disable_3();
  public void Disable()
    { Disable_3(); }

  private native void TerminateApp_4();
  public void TerminateApp()
    { TerminateApp_4(); }

  private native long CreateDefaultPicker_5();
  public vtkAbstractPropPicker CreateDefaultPicker() {
    long temp = CreateDefaultPicker_5();

    if (temp == 0) return null;
    return (vtkAbstractPropPicker)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPhysicalEventPosition_6(double id0,double id1,double id2,int id3);
  public void SetPhysicalEventPosition(double id0,double id1,double id2,int id3)
    { SetPhysicalEventPosition_6(id0,id1,id2,id3); }

  private native void SetWorldEventPosition_7(double id0,double id1,double id2,int id3);
  public void SetWorldEventPosition(double id0,double id1,double id2,int id3)
    { SetWorldEventPosition_7(id0,id1,id2,id3); }

  private native void SetWorldEventOrientation_8(double id0,double id1,double id2,double id3,int id4);
  public void SetWorldEventOrientation(double id0,double id1,double id2,double id3,int id4)
    { SetWorldEventOrientation_8(id0,id1,id2,id3,id4); }

  private native void RightButtonPressEvent_9();
  public void RightButtonPressEvent()
    { RightButtonPressEvent_9(); }

  private native void RightButtonReleaseEvent_10();
  public void RightButtonReleaseEvent()
    { RightButtonReleaseEvent_10(); }

  private native void MiddleButtonPressEvent_11();
  public void MiddleButtonPressEvent()
    { MiddleButtonPressEvent_11(); }

  private native void MiddleButtonReleaseEvent_12();
  public void MiddleButtonReleaseEvent()
    { MiddleButtonReleaseEvent_12(); }

  private native void SetTouchPadPosition_13(double id0,double id1);
  public void SetTouchPadPosition(double id0,double id1)
    { SetTouchPadPosition_13(id0,id1); }

  private native void SetTouchPadPosition_14(double id0[]);
  public void SetTouchPadPosition(double id0[])
    { SetTouchPadPosition_14(id0); }

  private native double[] GetTouchPadPosition_15();
  public double[] GetTouchPadPosition()
    { return GetTouchPadPosition_15(); }

  private native void SetPhysicalTranslation_16(vtkCamera id0,double id1,double id2,double id3);
  public void SetPhysicalTranslation(vtkCamera id0,double id1,double id2,double id3)
    { SetPhysicalTranslation_16(id0,id1,id2,id3); }

  private native void SetTranslation3D_17(double id0[]);
  public void SetTranslation3D(double id0[])
    { SetTranslation3D_17(id0); }

  private native double[] GetTranslation3D_18();
  public double[] GetTranslation3D()
    { return GetTranslation3D_18(); }

  private native double[] GetLastTranslation3D_19();
  public double[] GetLastTranslation3D()
    { return GetLastTranslation3D_19(); }

  private native boolean GetDone_20();
  public boolean GetDone()
    { return GetDone_20(); }

  public vtkRenderWindowInteractor3D() { super(); }

  public vtkRenderWindowInteractor3D(long id) { super(id); }
  public native long   VTKInit();

}
